@@ -50,7 +50,7 @@ Usage
 
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -101,7 +101,6 @@ Usage
 
 # stdlib
 import itertools
-import pathlib
 import re
 import sre_parse
 from sre_constants import (
@@ -133,21 +132,20 @@ from textwrap import dedent
 from typing import Any, Callable, List, Pattern, Tuple
 
 # 3rd party
-import importlib_resources
+import dict2css
 from consolekit.terminal_colours import Fore
 from docutils import nodes
 from docutils.nodes import Node, system_message
 from docutils.parsers.rst import roles
+from domdf_python_tools.paths import PathPlus
 from sphinx.application import Sphinx
 from sphinx.ext.autodoc import UNINITIALIZED_ATTR, ModuleDocumenter
 from sphinx.util.docutils import SphinxRole
-from sphinx.util.fileutil import copy_asset
 from sphinx.writers.html import HTMLTranslator
 
 # this package
-from sphinx_toolbox import __version__
 from sphinx_toolbox.more_autodoc.variables import VariableDocumenter
-from sphinx_toolbox.utils import SphinxExtMetadata, flag
+from sphinx_toolbox.utils import SphinxExtMetadata, flag, metadata_add_version
 
 __all__ = [
 		"RegexDocumenter",
@@ -157,6 +155,7 @@ __all__ = [
 		"parse_regex_flags",
 		"no_formatting",
 		"span",
+		"copy_asset_files",
 		"setup",
 		]
 
@@ -708,27 +707,42 @@ def depart_regex_node(translator: HTMLTranslator, node: RegexNode):
 	translator.body.pop(-1)
 
 
-def copy_asset_files(app: Sphinx, exc):
+def copy_asset_files(app: Sphinx, exception: Exception = None):
 	"""
 	Copy additional stylesheets into the HTML build directory.
 
-	:param app: The Sphinx app.
-	:param exc:
+	:param app: The Sphinx application.
+	:param exception: Any exception which occurred and caused Sphinx to abort.
 
 	.. versionadded:: 1.2.0
 	"""
 
-	# this package
-	import sphinx_toolbox.more_autodoc
+	if exception:  # pragma: no cover
+		return
 
-	if exc is None:  # build succeeded
-		with importlib_resources.path(sphinx_toolbox.more_autodoc, "regex.css") as cssfile:
-			copy_asset(str(pathlib.Path(cssfile)), str(pathlib.Path(app.outdir) / "_static"))
+	style = {
+			"span.regex_literal": {"color": "dimgrey"},
+			"span.regex_at": {"color": "orangered"},
+			"span.regex_repeat_brace": {"color": "orangered"},
+			"span.regex_branch": {"color": "orangered"},
+			"span.regex_subpattern": {"color": "dodgerblue"},
+			"span.regex_in": {"color": "darkorange"},
+			"span.regex_category": {"color": "darkseagreen"},
+			"span.regex_repeat": {"color": "orangered"},
+			"span.regex_any": {"color": "orangered"},
+			"code.regex": {"font-size": "80%"},
+			"span.regex": {"font-weight": "bold"},
+			}
+
+	static_dir = PathPlus(app.outdir) / "_static"
+	static_dir.maybe_make(parents=True)
+	(static_dir / "regex.css").write_clean(dict2css.dumps(style, minify=True))
 
 
 regex_parser = HTMLRegexParser()
 
 
+@metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc.regex`.
@@ -752,7 +766,4 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.add_css_file("regex.css")
 	app.connect("build-finished", copy_asset_files)
 
-	return {
-			"version": __version__,
-			"parallel_read_safe": True,
-			}
+	return {"parallel_read_safe": True}
